@@ -123,7 +123,7 @@ class ClBuilderUpdateAction(Action):
                              "repository"),
                       'method': 'Builder.syncRepositories(eachvar,True)',
                       'condition': lambda Get: (
-                          Get('cl_builder_binary_set') == "on" and
+                          Get('cl_builder_usetag_set') == "on" and
                           not Get('update.cl_update_binhost_data')[0])
                       },
                      # обновление переменных информации из binhost
@@ -132,13 +132,13 @@ class ClBuilderUpdateAction(Action):
                           'Builder.invalidateVariables('
                           '"cl_builder_linux_datavars")',
                       'condition': lambda Get: (
-                          Get('cl_builder_binary_set') == "on" and
+                          Get('cl_builder_usetag_set') == "on" and
                           not Get('update.cl_update_binhost_data')[0])
                       },
                      {'name': 'binhost_unavailable',
                       'error': __("Update server is unavailable"),
                       'condition': lambda Get: (
-                          Get('cl_builder_binary_set') == "on" and
+                          Get('cl_builder_usetag_set') == "on" and
                           not Get('update.cl_update_binhost_data')[0])
                       },
                      {'name': 'sync_reps',
@@ -150,7 +150,7 @@ class ClBuilderUpdateAction(Action):
                      {'name': 'check_binhost',
                       'method': 'Builder.check_binhost(True)',
                       'condition': lambda Get: Get(
-                          'cl_builder_binary_set') == "on"
+                          'cl_builder_usetag_set') == "on"
                       },
                      {'name': 'update_layman',
                       'message': __("Updating layman cache"),
@@ -380,7 +380,7 @@ class ClBuilderUpdateAction(Action):
                       'message': __("Cleaning the binary repository"),
                       'method': 'Builder.binaryCleaning()',
                       'condition': lambda Get: Get(
-                          'cl_builder_binary_set') == "off"
+                          'cl_builder_usetag_set') == "off"
                       },
                  ],
                  'depend': Tasks.has("update_other")
