@@ -1307,7 +1307,7 @@ class VariableClBuilderBranchName(Variable):
     def get(self):
         dv = self.Get('cl_builder_linux_datavars')
         if dv:
-            if "getbinpkg" in dv.Get('cl_features'):
+            if dv.GetBool('cl_update_usetag_set'):
                 return [Git.Reference.Tag for x in dv.Get('cl_update_rep_name')]
             else:
                 branch = dv.Get('cl_update_branch')
