@@ -76,6 +76,7 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
                     env.VariableClEnvData(),
                     env.VariableClEnvPath(),
                     env.VariableClEbuildPhase(),
+                    update.VariableClUpdateUsetagSet(section="update"),
                     update.VariableClUpdateWithBdepsSet(section="update"),
                     update.VariableClUpdateRepData(section="update"),
                     update.VariableClUpdateRepPath(section="update"),
@@ -151,6 +152,18 @@ class VariableClBuilderBinarySet(ReadonlyVariable):
         return "off"
 
 
+class VariableClBuilderUsetagSet(ReadonlyVariable):
+    """
+    Собираемый дистрибутив использует тэги при синхронизации репозиториев
+    """
+
+    def get(self):
+        dv = self.Get('cl_builder_linux_datavars')
+        if dv:
+            return dv.Get('cl_update_usetag_set')
+        return "off"
+
+
 class VariableClBuilderLinuxDatavars(ReadonlyVariable):
     """
     Переменные дистрибутива
